@@ -38,7 +38,7 @@
     Author: Christoph Reller <christoph.reller@gmail.com>
 """
 
-__version__ = '0.4.12'
+__version__ = '0.4.13'
 
 import contextlib
 import tempfile
@@ -49,6 +49,7 @@ import codecs
 import os
 import re
 
+from errno import ENOENT
 from os import path, getcwd, chdir
 from string import Template
 from subprocess import Popen, PIPE
@@ -63,9 +64,9 @@ from docutils.statemachine import ViewList
 
 from sphinx.errors import SphinxError
 try:
-    from sphinx.util.osutil import ensuredir, ENOENT
+    from sphinx.util.osutil import ensuredir
 except:
-    from sphinx.util import ensuredir, ENOENT
+    from sphinx.util import ensuredir
 
 from glob import glob
 
